# VerboLab

VerboLab is a Python package for building LLM (Language Learning Model) agents.

## Installation

You can install VerboLab using pip:
```bash
pip install verbolab
```

## Usage

```python
from verbolab.llms.models.quantized import StarlingLM7bBeta
llm = StarlingLM7bBeta()
```